Growing qcow2 files during block migration ?
Hi,
I love live migrations using the qemu-kvm block migration Feature (migrate -b) but I have a problem with it.
Lets say my source machine has a qcow2 file with virtual size of 60 GB but only 2 GB are in use. So the qcow2 file only has a size of 2 GB.
After block migration the resulting qcow2 file on the target machine has a size of 60 GB.
Also the migration is quite slow because it seems to transfer 60 GB instead of 2 GB.
Are there any workarounds, ideas/plans to optimize this ?
Thanks
Christoph
Quoted 7 lines · Christoph Adomeit
Lets say my source machine has a qcow2 file with virtual size of 60 GB but only 2 GB are in use. So the qcow2 file only has a size of 2 GB.
After block migration the resulting qcow2 file on the target machine has a size of 60 GB.
Also the migration is quite slow because it seems to transfer 60 GB instead of 2 GB.
Are there any workarounds, ideas/plans to optimize this ?
Yes. Although this isn't currently possible in mainline QEMU it is getting attention. There have been several recent threads on QED, image streaming, and block migration. Here is one which touches on zero sectors:
http://www.spinics.net/linux/fedora/libvir/msg28144.html
Stefan